@@ -170,7 +170,7 @@ class SingleClassifierEnhancer(Classifier):
         Returns the base classifier.
         :rtype: Classifier
         """
-        return Classifier(javabridge.call(self.jobject, "getClassifier", "()Lweka/classifiers/Classifier;"))
+        return Classifier(jobject=javabridge.call(self.jobject, "getClassifier", "()Lweka/classifiers/Classifier;"))
 
     @classifier.setter
     def classifier(self, classifier):
@@ -208,7 +208,7 @@ class FilteredClassifier(SingleClassifierEnhancer):
         :return: the filter in use
         :rtype: Filter
         """
-        return Filter(javabridge.call(self.jobject, "getFilter", "()Lweka/filters/Filter;"))
+        return Filter(jobject=javabridge.call(self.jobject, "getFilter", "()Lweka/filters/Filter;"))
 
     @filter.setter
     def filter(self, filtr):
@@ -535,7 +535,7 @@ class CostMatrix(JavaObject):
         """
         Initializes the matrix object.
         :param matrx: the matrix to copy
-        :type matrx: CostMatrix or ndarray
+        :type matrx: CostMatrix or ndarray or JB_Object
         :param num_classes: the number of classes
         :type num_classes: int
         """
@@ -557,6 +557,8 @@ class CostMatrix(JavaObject):
                     super(CostMatrix, self).__init__(cmatrix.jobject)
                 else:
                     raise Exception("Numpy array must be a square matrix!")
+            elif isinstance(matrx, javabridge.JB_Object):
+                super(CostMatrix, self).__init__(matrx)
             else:
                 raise Exception(
                     "Matrix must be either a CostMatrix or a 2-dimensional numpy array: " + str(type(matrx)))
@@ -723,6 +725,19 @@ class CostMatrix(JavaObject):
         """
         return javabridge.call(self.jobject, "toMatlab", "()Ljava/lang/String;")
 
+    @classmethod
+    def parse_matlab(cls, matlab):
+        """
+        Parses the costmatrix definition in matlab format and returns a matrix.
+        :param matlab: the matlab matrix string, eg [1 2; 3 4].
+        :type matlab: str
+        :return: the generated matrix
+        :rtype: CostMatrix
+        """
+        return CostMatrix(
+            matrx=javabridge.static_call(
+                "weka/classifiers/CostMatrix", "parseMatlab", "(Ljava/lang/String;)Lweka/classifiers/CostMatrix;", matlab))
+
 
 class Evaluation(JavaObject):
     """
@@ -1433,19 +1448,22 @@ class Evaluation(JavaObject):
     def predictions(self):
         """
         Returns the predictions.
-        :return: the predictions
+        :return: the predictions. None if not available
         :rtype: list
         """
         preds = javabridge.get_collection_wrapper(
             javabridge.call(self.jobject, "predictions", "()Ljava/util/ArrayList;"))
-        result = []
-        for pred in preds:
-            if javabridge.is_instance_of(pred, "weka/classifiers/evaluation/NominalPrediction"):
-                result.append(NominalPrediction(pred))
-            elif javabridge.is_instance_of(pred, "weka/classifiers/evaluation/NumericPrediction"):
-                result.append(NumericPrediction(pred))
-            else:
-                result.append(Prediction(pred))
+        if self.discard_predictions:
+            result = None
+        else:
+            result = []
+            for pred in preds:
+                if javabridge.is_instance_of(pred, "weka/classifiers/evaluation/NominalPrediction"):
+                    result.append(NominalPrediction(pred))
+                elif javabridge.is_instance_of(pred, "weka/classifiers/evaluation/NumericPrediction"):
+                    result.append(NumericPrediction(pred))
+                else:
+                    result.append(Prediction(pred))
         return result
 
     @classmethod
