@@ -12,7 +12,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # clusterers.py
-# Copyright (C) 2014 Fracpete (pythonwekawrapper at gmail dot com)
+# Copyright (C) 2014-2015 Fracpete (pythonwekawrapper at gmail dot com)
 
 import javabridge
 import logging
@@ -23,6 +23,7 @@ import weka.core.jvm as jvm
 import weka.core.utils as utils
 from weka.core.classes import JavaObject
 from weka.core.classes import OptionHandler
+from weka.core.classes import Random
 from weka.core.capabilities import Capabilities
 from weka.filters import Filter
 
@@ -97,7 +98,7 @@ class Clusterer(OptionHandler):
         :return: the clustering result
         :rtype: float
         """
-        return javabridge.call(self.jobject, "clusterInstance", "(Lweka/core/Instance;)D", inst.jobject)
+        return javabridge.call(self.jobject, "clusterInstance", "(Lweka/core/Instance;)I", inst.jobject)
 
     def distribution_for_instance(self, inst):
         """
@@ -171,7 +172,7 @@ class SingleClustererEnhancer(Clusterer):
         :return: the clusterer
         :rtype: Clusterer
         """
-        return Clusterer(javabridge.call(self.jobject, "getClusterer", "()Lweka/clusterers/Clusterer;"))
+        return Clusterer(jobject=javabridge.call(self.jobject, "getClusterer", "()Lweka/clusterers/Clusterer;"))
 
     @clusterer.setter
     def clusterer(self, clusterer):
@@ -209,7 +210,7 @@ class FilteredClusterer(SingleClustererEnhancer):
         :return: the filter
         :rtype: Filter
         """
-        return Filter(javabridge.call(self.jobject, "getFilter", "()Lweka/filters/Filter;"))
+        return Filter(jobject=javabridge.call(self.jobject, "getFilter", "()Lweka/filters/Filter;"))
 
     @filter.setter
     def filter(self, filtr):
@@ -317,6 +318,26 @@ class ClusterEvaluation(JavaObject):
             "(Lweka/clusterers/Clusterer;[Ljava/lang/String;)Ljava/lang/String;",
             clusterer.jobject, args)
 
+    @classmethod
+    def crossvalidate_model(cls, clusterer, data, num_folds, rnd):
+        """
+        Cross-validates the clusterer and returns the loglikelihood.
+        :param clusterer: the clusterer instance to evaluate
+        :type clusterer: Clusterer
+        :param data: the data to evaluate on
+        :type data: Instances
+        :param num_folds: the number of folds
+        :type num_folds: int
+        :param rnd: the random number generator to use
+        :type rnd: Random
+        :return: the cross-validated loglikelihood
+        :rtype: float
+        """
+        return javabridge.static_call(
+            "Lweka/clusterers/ClusterEvaluation;", "crossValidateModel",
+            "(Lweka/clusterers/DensityBasedClusterer;Lweka/core/Instances;ILjava/util/Random;)D",
+            clusterer.jobject, data.jobject, num_folds, rnd.jobject)
+
 
 def main():
     """
